pub struct ExtractedMesh {
pub transform: AffineTransform,
pub cpu_mesh_uuid: AssetUUID,
pub gpu_mesh: AssetHandle<GpuMesh>,
pub material: Option<AssetHandle<Box<dyn Material>>>,
}Expand description
A flat, GPU-friendly representation of a single mesh to be rendered.
This struct contains all the necessary information, copied from various ECS components, required to issue a draw call for a mesh.
Fields
transform: AffineTransformThe world-space transformation matrix of the mesh, derived from GlobalTransform.
cpu_mesh_uuid: AssetUUIDThe UUID of the loaded CPU Mesh. Used for debugging or mapping.
gpu_mesh: AssetHandle<GpuMesh>A handle to the uploaded GPU mesh data.
material: Option<AssetHandle<Box<dyn Material>>>A handle to the material to be used for rendering.
If None, a default material should be used.