pub struct RecipeSerializationLane { /* private fields */ }Expand description
A serialization strategy that uses a sequence of commands (SceneRecipe).
This lane is designed for flexibility. The command-based format is a good foundation for editor tools, scene patching, and potential streaming in the future.
Implementations